@@ -139,12 +139,18 @@ class GeoArray(object):
 
     def _validate_nodataVal(self):
         """Check if a given nodata value is within the valid value range of the data type."""
-        if (np.issubdtype(self.dtype, np.integer) and
-           not np.can_cast(self._initParams['nodata'], self.dtype)) or \
-           (np.issubdtype(self.dtype, np.floating) and
-           not np.can_cast(float(self._initParams['nodata']), self.dtype)):
+        _nodata = self._initParams['nodata']
+
+        if np.issubdtype(self.dtype, np.integer):
+            dt_min, dt_max = np.iinfo(self.dtype).min, np.iinfo(self.dtype).max
+        elif np.issubdtype(self.dtype, np.floating):
+            dt_min, dt_max = np.finfo(self.dtype).min, np.finfo(self.dtype).max
+        else:
+            return
+
+        if not dt_min <= _nodata <= dt_max:
             raise ValueError("The given no-data value (%s) is out range for data type %s."
-                             % (self._initParams['nodata'], self.dtype))
+                             % (self._initParams['nodata'], str(np.dtype(self.dtype))))
 
     @property
     def arr(self):
